@@ -60,10 +60,10 @@ int main(int argc, char **argv) {
 	lnf_rec_init(&recp);
 	lnf_mem_init(&memp);
 
-	lnf_mem_fastaggr(memp, LNF_FAST_AGGR_BASIC);
+//	lnf_mem_fastaggr(memp, LNF_FAST_AGGR_BASIC);
 
 	/* set rules for aggregation srcip/24,srcport,dstas */
-	lnf_mem_fadd(memp, LNF_FLD_SRCADDR, LNF_AGGR_KEY|LNF_SORT_DESC, 24, 64);
+//	lnf_mem_fadd(memp, LNF_FLD_SRCADDR, LNF_AGGR_KEY|LNF_SORT_DESC, 24, 64);
 	lnf_mem_fadd(memp, LNF_FLD_SRCPORT, LNF_AGGR_KEY, 0, 0); 
 	lnf_mem_fadd(memp, LNF_FLD_DSTAS, LNF_AGGR_KEY, 0, 0);
 
