@@ -1,6 +1,6 @@
 #!/bin/sh 
 
-LIBNF_VERSION="1.07"
+LIBNF_VERSION="1.08"
 
 NFDUMP="nfdump-1.6.13"
 NFDUMP_MD5="f5e916049aec1b531c63303b92270d42"
@@ -34,6 +34,7 @@ rm -rf nfdump/ $NFDUMP
 tar xzf $NFDUMP_SRC || exit 1
 mv $NFDUMP nfdump  || exit 1
 (cd nfdump && patch -p1 < ../nfdump-bugs.patch && cd .. ) || exit 1
+(cd nfdump && patch -p1 < ../nfdump-leak.patch && cd .. ) || exit 1
 
 echo ""
 echo "##########################################################"
@@ -86,6 +87,9 @@ for f in $FILES ; do
 	(cd src && rm -f $f && ln -s ../nfdump/bin/$f && cd ..) || exit 1
 done
 
+rm src/grammar.c
+rm src/scanner.c
+
 echo ""
 echo "##########################################################"
 echo "# STAGE 3: checking definitions of all items in libnf    #"
