@@ -967,14 +967,14 @@ static int inline lnf_field_fset_EMPTY_(master_record_t *m, void *p, bit_array_t
 
 /* ----------------------- */
 static int inline lnf_field_fget_CALC_DURATION(master_record_t *m, void *p, bit_array_t *e) { 
-	*((double *)p) = LNF_DURATION;
+	*((uint64_t *)p) = LNF_DURATION;
 	return LNF_OK;
 }
 
 /* ----------------------- */
 static int inline lnf_field_fget_CALC_BPS(master_record_t *m, void *p, bit_array_t *e) { 
 	if (LNF_DURATION > 0) {
-		*((double *)p) = m->dOctets / LNF_DURATION / 1000 * 8;
+		*((double *)p) = (m->dOctets * 8) / (LNF_DURATION / 1000.0);
 		return LNF_OK;
 	} else {
 		*((double *)p) = 0;
@@ -985,7 +985,7 @@ static int inline lnf_field_fget_CALC_BPS(master_record_t *m, void *p, bit_array
 /* ----------------------- */
 static int inline lnf_field_fget_CALC_PPS(master_record_t *m, void *p, bit_array_t *e) { 
 	if (LNF_DURATION > 0) {
-		*((double *)p) = m->dPkts / LNF_DURATION / 1000 * 8;
+		*((double *)p) = m->dPkts / (LNF_DURATION / 1000.0);
 		return LNF_OK;
 	} else {
 		*((double *)p) = 0;
@@ -1462,8 +1462,8 @@ lnf_field_def_t lnf_fields_def[] = {
 // pod:  Calculated items
 // pod:  =====================
 	[LNF_FLD_CALC_DURATION] = {
-		LNF_DOUBLE,		LNF_AGGR_SUM,	LNF_SORT_NONE,	
-		"duration",	"Flow duration",
+		LNF_UINT64,		LNF_AGGR_SUM,	LNF_SORT_NONE,	
+		"duration",	"Flow duration (in miliseconds)",
 		lnf_field_fget_CALC_DURATION,
 		lnf_field_fset_EMPTY_},
 
@@ -1512,7 +1512,7 @@ int lnf_fld_info(int field, int info, void *data, size_t size) {
 	char buf[LNF_INFO_BUFSIZE];
 
 	if (info == LNF_FLD_INFO_FIELDS) {
-		int *fld  = buf;
+		int *fld  = (int *)buf;
 		int x = 0;
 		/* find ID for field */
 		for (i = LNF_FLD_ZERO_; i < LNF_FLD_TERM_; i++) {
