@@ -56,6 +56,10 @@
 #include <stdlib.h>
 #include <errno.h>
 
+#ifdef LNF_THREADS
+#include <pthread.h>
+#endif
+
 #include "nfdump_inline.c"
 #include "nffile_inline.c"
 
@@ -66,6 +70,8 @@
 /* Global Variables */
 extern extension_descriptor_t extension_descriptor[];
 char error_str[LNF_MAX_STRING];
+pthread_mutex_t lnf_nfdump_filter_mutex;	/* mutex for operations open/close file, filter init */
+
 
 #define FLOW_RECORD_NEXT(x) x = (common_record_t *)((pointer_addr_t)x + x->size)
 
@@ -252,6 +258,7 @@ int lnf_open(lnf_file_t **lnf_filep, const char * filename, unsigned int flags,
 		return LNF_ERR_NOMEM;
 	}
 
+
 	lnf_file->flags = flags;
 	/* open file in either read only or write only mode */
 	if (flags & LNF_WRITE) {
@@ -432,7 +439,7 @@ void lnf_close(lnf_file_t *lnf_file) {
 		CloseFile(lnf_file->nffile);
 	}
 
-	DisposeFile(lnf_file->nffile);
+	DisposeFile(lnf_file->nffile); 
 
 	PackExtensionMapList(lnf_file->extension_map_list);
 	FreeExtensionMaps(lnf_file->extension_map_list);
@@ -812,7 +819,8 @@ int lnf_rec_fget(lnf_rec_t *rec, int field, void * p) {
 
 /* initialize filter */
 /* returns LNF_OK or LNF_ERR_FILTER */
-int lnf_filter_init(lnf_filter_t **filterp, char *expr) {
+/* there is a new code for lnf_filter, however it is experimental so far */
+int lnf_filter_init_v1(lnf_filter_t **filterp, char *expr) {
 
 	lnf_filter_t *filter;	
 
@@ -820,10 +828,12 @@ int lnf_filter_init(lnf_filter_t **filterp, char *expr) {
 
 	if (filter == NULL) {
 		return LNF_ERR_NOMEM;
-	}	
+	}
+
+	filter->v2filter = 0;	/* nitialised as V1 - nfdump filter */	
 
 	filter->engine = CompileFilter(expr);
-	
+
 	if ( !filter->engine ) {
 		free(filter);
 		return LNF_ERR_FILTER;
@@ -834,23 +844,11 @@ int lnf_filter_init(lnf_filter_t **filterp, char *expr) {
 	return LNF_OK;
 }
 
-/* matches the record agains filter */
-/* returns 1 - record was matched, 0 - record wasn't matched */
-int lnf_filter_match(lnf_filter_t *filter, lnf_rec_t *rec) {
-
-	filter->engine->nfrecord = (uint64_t *)rec->master_record;
-
-	return  (*filter->engine->FilterEngine)(filter->engine);
-}
-
-void lnf_filter_free(lnf_filter_t *filter) {
-
-	/* TODO nfdump do not have code to release filter :-( */
-	if (filter == NULL) {
-		return;
-	}
-
-	free(filter);
+/* call the proper version of the filter initialisation */
+/* So far we use V1 - original nfdump filter. In future */
+/* it will be replaced by new code V2 - libnf filter */
+int lnf_filter_init(lnf_filter_t **filterp, char *expr) {
+	return lnf_filter_init_v1(filterp, expr);
 }
 
 /************************************************************/
@@ -873,6 +871,13 @@ int lnf_fld_type(int field) {
 /* Errrr handling - needs to be updated for threades        */
 /************************************************************/
 
+/* get error string */
+void lnf_error(const char *buf, int buflen) {
+
+	strncpy((char *)buf, error_str, buflen - 1);
+
+}
+
 /* set error string */
 void lnf_seterror(char *format, ...) {
 va_list args;
@@ -880,6 +885,7 @@ va_list args;
 	va_start(args, format);
 	vsnprintf(error_str, LNF_MAX_STRING - 1, format, args);
 	va_end(args);
+
 }
 
 /* compatibility with nfdump */
@@ -895,9 +901,3 @@ va_list args;
 void LogInfo(char *format, ...) { }
 void format_number(uint64_t num, char *s, int scale, int fixed_width) { } 
 
-/* get error string */
-void lnf_error(const char *buf, int buflen) {
-
-	strncpy((char *)buf, error_str, buflen - 1);
-
-}
