@@ -1,4 +1,7 @@
 
+#ifndef _LIBNF_INTERNAL_H
+#define _LIBNF_INTERNAL_H
+
 
 #define _HAVE_LIBNF_STRUCT_H_ 1
 /* 
@@ -7,6 +10,12 @@
 * and then is included into basic libnf documentation 
 */
 
+#include "config.h"
+
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <nffile.h>
@@ -30,7 +39,6 @@
 #define HAVE_HTONLL 1
 #endif
 
-
 /* list of maps used in file taht we create */
 typedef struct lnf_map_list_s {
 	bit_array_t				 bit_array;
@@ -39,9 +47,16 @@ typedef struct lnf_map_list_s {
 } lnf_map_list_t;
 
 
+
 /* structure representing a filter */
 typedef struct lnf_filter_s {
 	FilterEngine_data_t	*engine;
+	int					v2filter; /* is V2 - libnf only fiter */
+
+	/* structures for new filter */
+	//lnf_filter_node_t	*root;
+	void				*root;
+
 } lnf_filter_t;
 
 
@@ -130,6 +145,7 @@ typedef struct lnf_mem_s {
 	int* thread_id_key;				/* id when threads are not supported */
 #endif
 	int thread_status[LNF_MAX_THREADS];		/* status of the current thread */
+#define LNF_TH_EMPTY 0x0			/* empty thread - no records written so far  */
 #define LNF_TH_WRITE 0x1			/* writing record - set after first write */
 #define LNF_TH_MERGE 0x2			/* writing done - ready for merge */
 #define LNF_TH_MERGING 0x3			/* merging thread */
@@ -159,7 +175,7 @@ void lnf_mem_fastaggr_callback(char *key, char *hval, char *uval, void *lnf_mem)
 void lnf_mem_aggr_callback(char *key, char *hval, char *uval, void *lnf_mem);
 int lnf_mem_sort_callback(char *key1, char *val1, char *key2, char *val2, void *p);
 int lnf_mem_done(lnf_mem_t *lnf_mem);
-
+int lnf_mem_read_next(lnf_mem_t *lnf_mem, char **pkey, char **pval);
 
 /* structure for fast aggregation support */
 typedef struct lnf_fastaggr_s {
@@ -170,3 +186,6 @@ typedef struct lnf_fastaggr_s {
 	uint64_t	aggr_flows;
 } lnf_fastaggr_t;
 
+
+#endif /* _LIBNF_INTERNAL_H */
+
